/*
 * Copyright (c) 2020, Max Klein
 *
 * This file is part of the tree-finder library, distributed under the terms of
 * the BSD 3 Clause license. The full license can be found in the LICENSE file.
 */
import { Tag, Tree } from "./util";
import "../style/breadcrumbs.less";
export class TreeFinderBreadcrumbsElement extends HTMLElement {
    constructor() {
        super(...arguments);
        this._initialized = false;
    }
    connectedCallback() {
        if (!this._initialized) {
            this.create_shadow_dom();
            this._initialized = true;
        }
    }
    async init(path) {
        this.innerHTML = Tree.breadcrumbsSpans(path);
    }
    create_shadow_dom() {
        this.attachShadow({ mode: "open" });
        const crumbsSlot = `<slot></slot>`;
        this.shadowRoot.innerHTML = Tag.html `
      <style>
        .tf-breadcrumbs-top {
          display: flex;
          align-items: flex-start;
        }
      </style>
      <div class="tf-breadcrumbs-top">
        ${crumbsSlot}
      </div>
    `;
        [this.shadowSheet, this.top] = this.shadowRoot.children;
    }
}
(function (TreeFinderBreadcrumbsElement) {
    function get() {
        if (document.createElement("tree-finder-breadcrumbs").constructor === HTMLElement) {
            customElements.define("tree-finder-breadcrumbs", TreeFinderBreadcrumbsElement);
        }
        return customElements.get('tree-finder-breadcrumbs');
    }
    TreeFinderBreadcrumbsElement.get = get;
})(TreeFinderBreadcrumbsElement || (TreeFinderBreadcrumbsElement = {}));
TreeFinderBreadcrumbsElement.get();
//# sourceMappingURL=breadcrumbs.js.map