/*
 * Copyright (c) 2020, Max Klein
 *
 * This file is part of the tree-finder library, distributed under the terms of
 * the BSD 3 Clause license. The full license can be found in the LICENSE file.
 */
export const DEFAULT_COL = "path";
export class Content {
    constructor(row) {
        this._isOpen = false;
        this.isDir = row.kind === "dir";
        this.row = row;
    }
    close() {
        this._isOpen = false;
    }
    fetchChildren(refresh = false) {
        if (!this.isDir || (!refresh && this._children)) {
            return;
        }
        this._children = this.row.getChildren().map((c) => new Content(c));
    }
    getPathAtDepth(depth = 0, fill) {
        const pth = this.row.path.slice(depth);
        if (fill !== undefined && pth.length > 1) {
            return [...Array(pth.length - 1).fill(fill), pth[pth.length - 1]];
        }
        else {
            return pth;
        }
    }
    open(refresh = false) {
        this.fetchChildren(refresh);
        this._isOpen = true;
    }
    get children() {
        return this._children;
    }
    get isOpen() {
        return this._isOpen;
    }
    get name() {
        return (this.row.path && this.row.path.length) ? this.row.path[this.row.path.length - 1] : "";
    }
}
//# sourceMappingURL=content.js.map