import { TreeFinderBreadcrumbsElement } from "./breadcrumbs";
import { ContentsModel } from "./model";
import { TreeFinderGridElement } from "./grid";
import { Tag } from "./util";
// import panelCSS from "../style/grid/index.module.less";
TreeFinderBreadcrumbsElement.get();
TreeFinderGridElement.get();
export class TreeFinderPanelElement extends HTMLElement {
    constructor() {
        super(...arguments);
        this._initialized = false;
    }
    connectedCallback() {
        if (!this._initialized) {
            this.create_shadow_dom();
            this._initialized = true;
        }
    }
    clear() {
        this.innerHTML = Tag.html `
      <tree-finder-breadcrumbs class="tf-panel-breadcrumbs" slot="breadcrumbs"></tree-finder-breadcrumbs>
      <div class="tf-panel-filter" slot="filter"></div>
      <tree-finder-grid class="tf-panel-grid" slot="grid"></tree-finder-grid>
    `;
        [this.breadcrumbs, this.filter, this.grid] = this.children;
    }
    async init(root, options = {}) {
        // const {
        //   openChildren = true,
        // } = options;
        // this.options = {
        //   openChildren,
        // }
        this.clear();
        const gridOptions = {
            doWindowReize: options.doWindowReize,
        };
        const modelOptions = {
            columnNames: options.columnNames,
            doRefetch: options.doRefetch,
        };
        this.model = new ContentsModel(root, modelOptions);
        this.model.crumbSubject.subscribe({
            next: x => this.breadcrumbs.init(x),
        });
        this.grid.init(this.model, gridOptions);
        await this.draw();
    }
    async draw() {
        await this.grid.draw();
    }
    create_shadow_dom() {
        this.attachShadow({ mode: "open" });
        const breadcrumbsSlot = `<slot name="breadcrumbs"></slot>`;
        const filterSlot = `<slot name="filter"></slot>`;
        const gridSlot = `<slot name="grid"></slot>`;
        this.shadowRoot.innerHTML = Tag.html `
      <style>
      </style>
      <div class="tf-panel-breadcrumbs-container">
        ${breadcrumbsSlot}
      </div>
      <div class="tf-panel-filter-container">
        ${filterSlot}
      </div>
      <div class="tf-panel-grid-container">
        ${gridSlot}
      </div>
    `;
        [this.shadowSheet, this.breadcrumbsContainer, this.filterContainer, this.gridContainer] = this.shadowRoot.children;
    }
}
(function (TreeFinderPanelElement) {
    function get() {
        if (document.createElement("tree-finder").constructor === HTMLElement) {
            customElements.define("tree-finder", TreeFinderPanelElement);
        }
        return customElements.get('tree-finder');
    }
    TreeFinderPanelElement.get = get;
})(TreeFinderPanelElement || (TreeFinderPanelElement = {}));
TreeFinderPanelElement.get();
//# sourceMappingURL=panel.js.map